

'use strict';
{
  const globals = this;
  const django = globals.django || (globals.django = {});

  
  django.pluralidx = function(n) {
    const v = (n != 1);
    if (typeof v === 'boolean') {
      return v ? 1 : 0;
    } else {
      return v;
    }
  };
  

  /* gettext library */

  django.catalog = django.catalog || {};
  
  const newcatalog = {
    "(If left blank, owner will be admin)": "(Om det l\u00e4mnas blankt, kommer \u00e4garen bli admin)",
    "(at least {placeholder} characters)": "(\u00e5tminstone {placeholder} tecken)",
    "(current notification)": "aktuellt systemmeddelande",
    "(current version)": "(nuvarande version)",
    "1 Year": "1 \u00c5r",
    "1 month ago": "1 m\u00e5nad sedan",
    "1 week ago": "1 vecka sedan",
    "3 days ago": "3 dagar sedan",
    "30 Days": "30 Dagar",
    "7 Days": "7 Dagar",
    "A file is being uploaded. Are you sure you want to leave this page?": "En fil h\u00e5ller p\u00e5 att laddas upp. \u00c4r du s\u00e4ker p\u00e5 att du vill l\u00e4mna denna sida?",
    "A file with the same name already exists in this folder.": "En fil med samma namn existerar i denna mapp.",
    "API token is copied to the clipboard.": "API token \u00e4r kopierad till urklipp.",
    "About": "Om",
    "About Us": "Om Oss",
    "Abuse Content": "Missbruksinneh\u00e5ll",
    "Abuse Reports": "Missbruksrapporter",
    "Abuse Type": "Missbrukstyp",
    "Accept": "Acceptera",
    "Accepted": "Accepterad",
    "Accepter": "Accepteraren",
    "Access Log": "Accesslog",
    "Action": "Funktion",
    "Actions": "Funktioner",
    "Activate user immediately after registration. If unchecked, a user need to be activated by administrator or via activation email": "Aktivera anv\u00e4ndare direkt efter registrering. Om den inte \u00e4r markerad s\u00e5 beh\u00f6ver anv\u00e4ndaren bli aktiverad av administrat\u00f6r eller via aktiveringsmejl",
    "Activated": "Aktiverad",
    "Activated Users": "Aktiverade Anv\u00e4ndare",
    "Active": "Aktiv",
    "Active Users": "Aktiva Anv\u00e4ndare",
    "Activities": "Aktiviteter",
    "Add": "L\u00e4gg till",
    "Add Admin": "L\u00e4gg till Admin",
    "Add Admins": "L\u00e4gg till administrat\u00f6rer",
    "Add Institution": "L\u00e4gg till Institution",
    "Add Library": "L\u00e4gg till bibliotek",
    "Add Member": "L\u00e4gg till medlem",
    "Add Organization": "L\u00e4gg till Organisation",
    "Add Terms and Conditions": "L\u00e4gg till villkor",
    "Add User": "L\u00e4gg till anv\u00e4ndare",
    "Add admin": "L\u00e4gg till admin",
    "Add auto expiration": "L\u00e4gg till automatisk utg\u00e5ngsdatum",
    "Add group member": "L\u00e4gg till gruppmedlem",
    "Add institution": "L\u00e4gg till institution",
    "Add new notification": "Skapa nytt systemmeddelande",
    "Add new reviewer": "L\u00e4gg till granskare",
    "Add password protection": "L\u00e4gg till l\u00f6senordsskydd",
    "Add user": "L\u00e4gg till anv\u00e4ndare",
    "Added": "Tillagd",
    "Added user {user}": "Lade till anv\u00e4ndare {user}",
    "Admin": "Administrera",
    "Admin Login Logs": "Admin Login Loggar",
    "Admin Logs": "Admin-loggar",
    "Admin Operation Logs": "Admin \u00c5tg\u00e4rdsloggar",
    "Admin access": "Adminn \u00e5tkomst",
    "Admins": "Administrat\u00f6rer",
    "All": "Alla",
    "All Groups": "Alla grupper",
    "All Libraries": "Alla Kataloger",
    "All Notifications": "Alla systemmeddelanden",
    "All Public Links": "Alla Publika L\u00e4nkar",
    "All file types": "Alla filtyper",
    "Allow new user registrations. Uncheck this to prevent anyone from creating a new account.": "Till\u00e5t nya anv\u00e4ndarregistreringar. Kryssa ur f\u00f6r att hindra att vem som helst skapar ett nytt konto.",
    "Allow user to change library history settings": "Till\u00e5t anv\u00e4ndare till att \u00e4ndra bibliotekets historikinst\u00e4llningar",
    "Allow user to clean library trash": "Till\u00e5t anv\u00e4ndare att rensa katalogskr\u00e4p",
    "Allow user to create encrypted libraries": "Till\u00e5t anv\u00e4ndare att skapa krypterade kataloger",
    "An integer that is greater than 0 or equal to -2.": "En siffra som \u00e4r st\u00f6rre \u00e4n 0 eller lika med -2.",
    "An integer that is greater than or equal to 0.": "En siffra som \u00e4r st\u00f6rre \u00e4n eller lika med 0.",
    "An internal link is a link to a file or folder that can be accessed by users with read permission to the file or folder.": "En intern l\u00e4nk \u00e4r en l\u00e4nk till en fil eller mapp som kan \u00f6ppnas av en anv\u00e4ndare med l\u00e4s r\u00e4ttigheter till filen eller mappen.",
    "Anonymous User": "Anonnym anv\u00e4ndare",
    "App Name": "App Namn",
    "Are you sure to delete": "\u00c4r du s\u00e4ker p\u00e5 att du vill ta bort",
    "Are you sure to revoke access of user {placeholder} ?": "\u00c4r du s\u00e4ker p\u00e5 att du vill ta bort tilltr\u00e4de f\u00f6r anv\u00e4ndare {placeholder}?",
    "Are you sure you want to clear trash?": "\u00c4r du s\u00e4ker p\u00e5 att du vill t\u00f6mma papperskorgen?",
    "Are you sure you want to delete %s ?": "\u00c4r du s\u00e4ker p\u00e5 att du vill ta bort %s ?",
    "Are you sure you want to delete the notification ?": "\u00c4r du s\u00e4ker p\u00e5 att du vill ta bort notifikationen?",
    "Are you sure you want to delete the selected user(s) ?": "\u00c4r du s\u00e4ker p\u00e5 att du vill ta bort valda anv\u00e4ndare?",
    "Are you sure you want to delete the share link?": "\u00c4r du s\u00e4ker p\u00e5 att du vill ta bort delningsl\u00e4nken?",
    "Are you sure you want to delete {placeholder} ?": "\u00c4r du s\u00e4ker p\u00e5 att du vill ta bort {placeholder}?",
    "Are you sure you want to delete {placeholder} completely?": "\u00c4r du s\u00e4ker p\u00e5 att du vill ta bort {placeholder} helt?",
    "Are you sure you want to disconnect?": "\u00c4r det s\u00e4ker p\u00e5 att du vill avsluta anslutning?",
    "Are you sure you want to remove {placeholder} ?": "\u00c4r du s\u00e4ker p\u00e5 att du vill ta bort {placeholder}?",
    "Are you sure you want to reset the password of {placeholder} ?": "\u00c4r du s\u00e4ker p\u00e5 att du vill \u00e5terst\u00e4lla l\u00f6senordet f\u00f6r {placeholder}?",
    "Are you sure you want to restore this library?": "\u00c4r du s\u00e4ker att du vill \u00e5terst\u00e4lla denna katalog?",
    "Are you sure you want to restore {placeholder}?": "\u00c4r du s\u00e4ker p\u00e5 att du vill \u00e5terst\u00e4lla {placeholder}?",
    "Are you sure you want to revoke the admin permission of {placeholder} ?": "\u00c4r du s\u00e4ker p\u00e5 att du vill ta bort admin r\u00e4ttigheter f\u00f6r {placeholder}?",
    "Are you sure you want to set {placeholder} as Admin?": "\u00c4r du s\u00e4ker p\u00e5 att du vill s\u00e4tta {placeholder} som Admin?",
    "Are you sure you want to unlink this device?": "\u00c4r du s\u00e4ker p\u00e5 att du vill avl\u00e4nka enheten?",
    "Are you sure you want to unpublish this library?": "\u00c4r du s\u00e4ker p\u00e5 att du vill avpublicera denna katalog?",
    "Are you sure you want to unshare {placeholder} ?": "\u00c4r du s\u00e4ker p\u00e5 att du vill avl\u00e4nka {placeholder}?",
    "At server": "P\u00e5 server",
    "Audio": "Audio",
    "Audit Admin": "Anv\u00e4ndaradmin",
    "Auto deletion": "Auto borttagning",
    "Automatically delete files that are not modified within certain days:": "Ta bort filer automatiskt som inte har \u00e4ndrats inom antal dagar:",
    "Avatar": "Avatar",
    "Avatar:": "Avatar:",
    "Back": "Bak\u00e5t",
    "Besides Write permission, user can also share the library.": "Ut\u00f6ver Skriv r\u00e4ttigheter, kan anv\u00e4ndare dela katalogen.",
    "Branding": "Branding",
    "Broken (please contact your administrator to fix this library)": "Trasigt (v\u00e4nligen kontakta din administrat\u00f6r f\u00f6r att laga detta bibliotek)",
    "Broken ({repo_id_placeholder})": "Trasig ({repo_id_placeholder})",
    "By name ascending": "P\u00e5 namn stigande",
    "By name descending": "P\u00e5 namn fallande",
    "By size ascending": "P\u00e5 storlek stigande",
    "By size descending": "P\u00e5 storlek fallande",
    "By time ascending": "P\u00e5 tid stigande",
    "By time descending": "P\u00e5 tid fallande",
    "Can not copy directory %(src)s to its subdirectory %(des)s": "Kan inte kopiera katalog %(src)s till dess underkatalog %(des)s",
    "Can not move directory %(src)s to its subdirectory %(des)s": "Kan inte flytta katalog %(src)s till dess underkatalog %(des)s",
    "Cancel": "Avbryt",
    "Cancel All": "Avbryt alla",
    "Change": "\u00c4ndra",
    "Change Password": "Byt L\u00f6senord",
    "Change Password of Library {placeholder}": "\u00c4ndra l\u00f6senord f\u00f6r katalogen {placeholder}",
    "Changes": "\u00c4ndringar",
    "Choose date": "V\u00e4lj datum",
    "Clean": "Rensa",
    "Clean succeeded.": "St\u00e4dning lyckades",
    "Cleaned trash": "Rensat skr\u00e4p",
    "Clear": "Rensa",
    "Clear Trash": "Rensa Papperskorg",
    "Clear files in trash and history\uff1a": "Rensa filer i skr\u00e4pkorgen och historik:",
    "Clients": "Klienter",
    "Close": "St\u00e4ng",
    "Column": "Kolumn",
    "Community Edition": "Community Edition",
    "Confirm": "Bekr\u00e4fta",
    "Confirm Password": "Bekr\u00e4fta l\u00f6senord",
    "Connect": "Anslut",
    "Contact Email": "Kontakt Mejladress",
    "Contact Email:": "Kontakt mejladress:",
    "Contact Information": "Kontaktinformation",
    "Contact information is required.": "Kontaktinformation kr\u00e4vs.",
    "Content Scan Records": "Inneh\u00e5ll Skanrapporter",
    "Copy": "Kopiera",
    "Copy selected item(s) to:": "Kopiera valda objekt till:",
    "Copy {num} items": "Kopiera {num} objekt",
    "Copy {placeholder} to": "Kopiera {placeholder} till",
    "Copyright Infringement": "Upphovsr\u00e4ttsintr\u00e5ng",
    "Count": "Antal",
    "Create": "Skapa",
    "Create Group": "Skapa grupp",
    "Create Library": "Skapa Katalog",
    "Create Report": "Skapa rapport",
    "Create a draft from this file, instead of editing it directly.": "Skapa ett utkast fr\u00e5n denna fil, ist\u00e4llet f\u00f6r att \u00e4ndra den direkt.",
    "Create a new tag": "Skapa en ny tagg",
    "Created": "Skapad",
    "Created At": "Skapad Av",
    "Created Files": "Skapade Filer",
    "Created draft": "Skapat utkast",
    "Created file": "Skapat fil",
    "Created folder": "Skapat mapp",
    "Created group {group_name}": "Skapade grupp {group_name}",
    "Created library": "Skapade katalog",
    "Created library {library_name} with {owner} as its owner": "Skapade katalog {library_name} med {owner} som \u00e4gare",
    "Created {n} files": "Skapat {n} filer",
    "Creator": "Skapad av",
    "Current Connected Devices": "Nuvarande Anslutna Enheter",
    "Current Library": "Nuvarande Katalog",
    "Current Path: ": "Nuvarande s\u00f6kv\u00e4g",
    "Current Version": "Nuvarande Version",
    "Current path: ": "Nuvarande s\u00f6kv\u00e4g:",
    "Custom CSS": "Egen CSS",
    "Custom file types": "Anpassade fil\u00e4ndelser ",
    "Daily Admin": "Dagligadmin",
    "Database": "Databas",
    "Date": "Datum",
    "Date Invalid.": "Datum Ogiltig.",
    "Default": "Standard",
    "Default Admin": "Standardadmin",
    "Delete": "Ta bort",
    "Delete Account": "Ta bort konto",
    "Delete Department": "Ta bort Avdelning",
    "Delete Expired Invitations": "Ta Bort Utg\u00e5ngna Inbjudningar",
    "Delete File": "Ta bort Fil",
    "Delete Folder": "Ta bort Mapp",
    "Delete Group": "Ta bort grupp",
    "Delete Institution": "Ta bort institution",
    "Delete Library": "Ta bort Katalog",
    "Delete Member": "Ta bort medlem",
    "Delete Notification": "Ta bort systemmeddelande",
    "Delete Organization": "Ta bort Organisation",
    "Delete T&C": "Ta bort T&C",
    "Delete Time": "Raderad tid",
    "Delete User": "Ta bort anv\u00e4ndare",
    "Delete Users": "Ta bort Anv\u00e4ndare",
    "Delete draft": "Tabort utkast",
    "Delete files from this device the next time it comes online.": "Ta bort filer fr\u00e5n denna enhet n\u00e4sta g\u00e5ng den kommer online.",
    "Deleted": "Borttagen",
    "Deleted Libraries": "Borttagna Kataloger",
    "Deleted Time": "Borttagen Tid",
    "Deleted directories": "Borttagna kataloger",
    "Deleted draft": "Tagit bort utkast",
    "Deleted file": "Tagit bort fil",
    "Deleted files": "Borttagna filer",
    "Deleted folder": "Tagit bort mapp",
    "Deleted group {group_name}": "Tog bort grupp {group_name}",
    "Deleted library": "Katalog borttagen",
    "Deleted library {library_name}": "Tog bort bibliotek {library_name}",
    "Deleted user {user}": "Tog bort anv\u00e4ndare {user}",
    "Departments": "Avdelningar",
    "Description": "Beskrivning",
    "Description is required": "Beskrivning kr\u00e4vs",
    "Desktop": "Skrivbord",
    "Details": "Detaljer",
    "Device": "Enhet",
    "Device Name": "Enhetsnamn",
    "Devices": "Enheter",
    "Direct Download Link:": "Direkt nedladdningsl\u00e4nk:",
    "Direct download link is copied to the clipboard.": "Direkt nedladdningsl\u00e4nk kopierat till urklipp.",
    "Directory": "Katalog",
    "Disable Two-Factor Authentication": "Avaktivera tv\u00e5faktorsautentisering",
    "Disconnect": "Avsluta",
    "Do not automatically delete files": "Ta inte bort filer automatiskt",
    "Document": "Dokument",
    "Document convertion failed.": "Misslyckades konvertera dokumentet",
    "Documents": "Dokument",
    "Don't ignore": "Ignorera inte",
    "Don't keep history": "Spara inte historik",
    "Don't replace": "Byt inte ut",
    "Don't send emails": "Skicka inga mail",
    "Download": "Ladda ner",
    "Download an example file": "Ladda ner en exempelfil",
    "Download and upload": "Ladda ner och ladda upp",
    "Draft": "Utkast",
    "Draft is a way to let you collaborate with others on files. You can create a draft from a file, edit the draft and then ask for a review. The original file will be updated only after the draft has been reviewed.": "Utkast \u00e4r ett s\u00e4tt g\u00f6r dig att samarbeta med andra i filer. Du kan skapa utkast av en fil, \u00e4ndra ett utkast och sedan efterfr\u00e5ga en granskning. Orginalfilen kommer d\u00e5 att uppdateras endast efter att utkast blivit granskad.",
    "Drafts": "F\u00f6rslag",
    "Drag and drop files or folders here.": "Dra och sl\u00e4pp filer eller mappar h\u00e4r.",
    "Edit": "\u00c4ndra",
    "Edit File": "Redigera Fil",
    "Edit labels": "\u00c4ndra markeringar",
    "Edit on cloud and download": "\u00c4ndra i molnet och ladda ner",
    "Edit on cloud only": "Redigera i molnet enbart",
    "Edit succeeded": "\u00c4ndring lyckades",
    "Edit succeeded.": "\u00c4ndring lyckades.",
    "Email": "Email",
    "Email Notification": "Mailnotis",
    "Email is invalid.": "Mailadress \u00e4r ogiltig.",
    "Emails": "Mailadresser",
    "Emails, separated by ','": "Mejladresser separerade med ','",
    "Enable Two-Factor Authentication": "Aktivera tv\u00e5faktorsautentisering",
    "Enable system admin to add Terms and Conditions, and all users will have to accept the terms.": "Till\u00e5t system admin till att l\u00e4gga till Villkor, samt att alla anv\u00e4ndare m\u00e5ste acceptera villkoren.",
    "Enable two factor authentication": "Aktivera tv\u00e5stegsautentisering",
    "Enable users to share libraries to any groups in the system.": "Aktivera anv\u00e4ndare till att dela kataloger till alla grupper i systemet.",
    "Encrypt": "Kryptera",
    "Encrypted library": "Krypterat bibliotek",
    "End date": "Slutdatum",
    "Enter characters to start searching": "Ange tecken f\u00f6r att p\u00e5b\u00f6rja s\u00f6kning",
    "Error": "Fel",
    "Errors": "Fel",
    "Exit Institution Admin": "Avsluta institutionsadmin",
    "Exit Organization Admin": "Avsluta Organisations Admin",
    "Exit System Admin": "L\u00e4mna Systemadmin",
    "Expiration": "Utg\u00e5ngsdatum",
    "Expiration Date:": "Utg\u00e5ngsdatum:",
    "Expiration days": "Utg\u00e5ngsdatum",
    "Expiration time": "Utg\u00e5ngstid",
    "Expired": "Utg\u00e5ngen",
    "Expired at": "Utg\u00e5ngen vid",
    "Export Excel": "Exportera Excel",
    "Extensions of text files that can be online previewed, each suffix is separated by a comma.": "Fil\u00e4ndelser f\u00f6r textfiler kan bli f\u00f6rhandsvisade online. Varje suffix \u00e4r separerade av komma.",
    "Failed": "Misslyckades",
    "Failed to add {email_placeholder}: {error_msg_placeholder}": "Misslyckades att l\u00e4gga till {email_placeholder}: {error_msg_placeholder}",
    "Failed to copy %(name)s": "Misslyckades att kopiera %(name)s",
    "Failed to copy %(name)s and %(amount)s other item(s).": "Misslyckades kopiera %(name)s och %(amount)s andra objekt.",
    "Failed to copy %(name)s.": "Misslyckades kopiera %(name)s.",
    "Failed to copy files to another library.": "Misslyckades kopiera filer till en annan katalog.",
    "Failed to delete %(virus_file) from library %(library): %(error_msg)": "Misslyckades ta bort %(virus_file) fr\u00e5n katalog %(library): %(error_msg)",
    "Failed to delete draft %(draft)s.": "Misslyckades ta bort utkast %(draft)s.",
    "Failed to delete {name}": "Misslyckades ta bort {name}",
    "Failed to delete {name}.": "Misslyckades ta bort {name}.",
    "Failed to ignore %(virus_file) from library %(library): %(error_msg)": "Misslyckade ignorera %(virus_file) fr\u00e5n katalog %(library): %(error_msg)",
    "Failed to move %(name)s and %(amount)s other item(s).": "Misslyckades flytta %(name)s och %(amount)s andra objekt.",
    "Failed to move %(name)s.": "Misslyckades flytta %(name)s.",
    "Failed to move files to another library.": "Misslyckades att flytta filer till en annan katalog.",
    "Failed to move {name}.": "Misslyckades att flytta {name}.",
    "Failed to publish draft %(draft)s.": "Misslyckades publicera utkast %(draft)s.",
    "Failed to send to {email_placeholder}: {errorMsg_placeholder}": "Misslyckades skicka till {email_placeholder}: {errorMsg_placeholder}",
    "Failed to unshare {name}": "Misslyckades sluta dela {name}",
    "Failed. Please check the network.": "Misslyckades. Kontrollera n\u00e4tverket.",
    "Favorites": "Favoriter",
    "File": "Fil",
    "File Access": "Filaccess",
    "File Operations": "Fil\u00e5tg\u00e4rder",
    "File Scan": "Fil Scan",
    "File Types": "Filtyper",
    "File Update": "Filuppdatering",
    "File Upload": "Filuppladdning",
    "File Uploading...": "Filen laddas upp...",
    "File already exists.": "Filen existerar redan.",
    "File does not exist.": "Filen existerar inte.",
    "File download is disabled: the share link traffic of owner is used up.": "Filnedladdning \u00e4r avst\u00e4ngt: delningsl\u00e4nktrafiken f\u00f6r anv\u00e4ndaren \u00e4r slut.",
    "File extensions can only be {placeholder}.": "Fil\u00e4ndelser kan enbart vara {placeholder}.",
    "File is locked by others.": "Filer l\u00e5sta av andra.",
    "File size is too large.": "Filstorleken \u00e4r f\u00f6r stor.",
    "Files": "Filer",
    "Folder": "Mapp",
    "Folder Permission": "Mappr\u00e4ttigheter",
    "Folder does not exist.": "Mapp existerar inte",
    "Folder upload is limited to Chrome, Firefox 50+, and Microsoft Edge.": "Mappuppladdning \u00e4r begr\u00e4nsad till Chrome, Firefox 50+ och Microsoft Edge",
    "Folders": "Mappar",
    "Force user to change password when account is newly added or reset by admin": "Tvinga anv\u00e4ndare att byta l\u00f6senord n\u00e4r ett konto lagts till eller \u00e5terst\u00e4llts av en administrat\u00f6r.",
    "Force user to use a strong password when sign up or change password.": "Tvinga anv\u00e4ndare att anv\u00e4nda ett starkt l\u00f6senord n\u00e4r ett konto skapas eller l\u00f6senord byts.",
    "Freeze user account when failed login attempts exceed limit.": "L\u00e5s anv\u00e4ndarkonto n\u00e4r antal misslyckade inloggningar n\u00e5tt en gr\u00e4ns.",
    "Generate": "Generera",
    "Global Address Book": "Global Adresslista",
    "Go to Library": "G\u00e5 till Katalog",
    "Greater than or equal to {minDays_placeholder} days": "St\u00f6rre \u00e4n eller lika med {minDays_placeholder} dagar",
    "Grid": "Rutn\u00e4t",
    "Group": "Grupp",
    "Group Permission": "Grupp R\u00e4ttigheter",
    "Group not found": "Grupp hittades inte",
    "Groups": "Grupper",
    "Guest": "G\u00e4st",
    "Handled": "Hanterad",
    "Help": "Hj\u00e4lp",
    "Hide": "D\u00f6lj",
    "History": "Historik",
    "History Setting": "Historik Inst\u00e4llning",
    "History Versions": "Versionshistorik",
    "IP": "IP",
    "If turn on, the desktop clients will not be able to sync a folder outside the default Seafile folder.": "Om detta \u00e4r p\u00e5slaget kommer desktop-klienten inte kunna synka mappar utanf\u00f6r standard Seafile-mappen.",
    "If you don't have any device with you, you can access your account using backup codes.": "Om du inte har din enhet med dig s\u00e5 kan du komma \u00e5t ditt konto med backup koder.",
    "Ignore": "Ignorera",
    "Ignored": "Ignorerad",
    "Image": "Bild",
    "Images": "Bilder",
    "Import Members": "Importera Medlemmar",
    "Import Users": "Importera Anv\u00e4ndare",
    "Import users": "Importera anv\u00e4ndare",
    "Import users from a .xlsx file": "Importera anv\u00e4ndare fr\u00e5n en .xlsx fil",
    "In all libraries": "I alla kataloger",
    "Inactive": "Inaktiv",
    "Indexing...": "Indexerar...",
    "Info": "Info",
    "Input file extensions here, separate with ','": "Ange fil\u00e4ndelser h\u00e4r, separerade med ','",
    "Institution": "Institution",
    "Institution Admin": "Institutionsadmin",
    "Institutions": "Institutioner",
    "Internal Link": "Intern l\u00e4nk",
    "Internal Server Error": "Internt serverproblem",
    "Internal link has been copied to clipboard": "Intern l\u00e4nk har blivit kopierad till urklipp",
    "Invalid destination path": "Felaktig destinationss\u00f6kv\u00e4g",
    "Invalid file size range.": "Ogiltig filstorleksintervall.",
    "Invalid filename.": "Felaktigt filnamn.",
    "Invalid month, should be yyyymm.": "Felaktig m\u00e5nad, ska vara yyyymm.",
    "Invitations": "Inbjudningar",
    "Invite Guest": "Bjud in G\u00e4st",
    "Invite Time": "Inbjudningstid",
    "Invited at": "Inbjuden vid",
    "Inviter": "Inbjudaren",
    "It is required.": "Det kr\u00e4vs.",
    "It may take some time, please wait.": "Det kan ta en stund, v\u00e4nligen v\u00e4nta.",
    "Keep full history": "Spara full historik",
    "LDAP": "LDAP",
    "LDAP(imported)": "LDAP(importerad)",
    "Label": "Markering",
    "Label Current State": "M\u00e4rk Nuvarande Status",
    "Labels": "Markeringar",
    "Language": "Spr\u00e5k",
    "Language Setting": "Spr\u00e5kinst\u00e4llning",
    "Last Access": "Senast Access",
    "Last Login": "Senast Inloggning",
    "Last Update": "Senaste uppdatering",
    "Last modified by": "Senast \u00e4ndrad av",
    "Leave": "L\u00e4mna",
    "Leave Group": "L\u00e4mna Grupp",
    "Leave Share": "L\u00e4mna delning",
    "Less than or equal to {maxDays_placeholder} days": "Mindre \u00e4n eller lika med {maxDays_placeholder} dagar",
    "Libraries": "Kataloger",
    "Library": "Katalog",
    "Library Type": "Katalogstyp",
    "Library can not be shared to owner.": "Katalogen kan inte delas till \u00e4garen.",
    "Limits": "Begr\u00e4nsningar",
    "Link": "L\u00e4nk",
    "Link has been copied to clipboard": "L\u00e4nken har blivit kopierad till urklipp",
    "Link:": "L\u00e4nk:",
    "Linked Devices": "L\u00e4nkade Enheter",
    "Links": "L\u00e4nkar",
    "List": "Lista",
    "List your account in global address book, so that others can find you by typing your name.": "Lista dina konton i den globala adresslistan, s\u00e5 att andra kan hitta dig genom att s\u00f6ka efter ditt namn.",
    "Local draft": "Lokalt utkast",
    "Local draft saved": "Lokalt utkast sparat",
    "Location": "Lokation",
    "Lock": "L\u00e5s",
    "Log out": "Logga ut",
    "Login": "Logga in",
    "Login Background Image": "Login Bakgrundsbild",
    "Logs": "Loggar",
    "Manage Members": "Managera medlemmar",
    "Manage group members": "Hantera gruppmedlemmar",
    "Mark all read": "Markera alla l\u00e4sta",
    "Member": "Medlem",
    "Members": "Medlemmar",
    "Message": "Meddelande",
    "Message (optional):": "Meddelande (valfritt):",
    "Mobile": "Mobil",
    "Modification Details": "Detaljer",
    "Modified": "\u00c4ndrad",
    "Modified files": "\u00c4ndrade filer",
    "Modifier": "\u00c4ndrad av",
    "Modify": "\u00c4ndra",
    "Month:": "M\u00e5nad:",
    "Monthly User Traffic": "M\u00e5nadsvis anv\u00e4ndartrafik",
    "More": "Mer",
    "More Operations": "Fler \u00e5tg\u00e4rder",
    "Move": "Flytta",
    "Move selected item(s) to:": "Flytta valda objekt till:",
    "Move {num} items": "Flytta {num} objekt",
    "Move {placeholder} to": "Flytta {placeholder} till",
    "Moved file": "Flyttat fil",
    "Moved folder": "Flyttat mapp",
    "My Groups": "Mina grupper",
    "My Libraries": "Mina Kataloger",
    "Name": "Namn",
    "Name is required": "Namn kr\u00e4vs",
    "Name is required.": "Namn kr\u00e4vs.",
    "Name should not include '/'.": "Namn ska inte inneh\u00e5lla '/'.",
    "Name(optional)": "Namn(valfritt)",
    "Network error": "N\u00e4tverksfel",
    "New": "Ny",
    "New Department": "Ny Avdelning",
    "New Department Library": "Ny Avdelningskatalog",
    "New Draft": "Nytt F\u00f6rslag",
    "New Excel File": "Ny Excel-fil",
    "New File": "Ny fil",
    "New Folder": "Ny Mapp",
    "New Group": "Ny grupp",
    "New Library": "Ny Katalog",
    "New Markdown File": "Ny Markdown-fil",
    "New Password": "Nytt L\u00f6senord",
    "New Password Again": "Nytt L\u00f6senord Igen",
    "New PowerPoint File": "Ny PowerPoint-fil",
    "New Sub-department": "Ny Underavdelning",
    "New Tag": "Ny Tagg",
    "New Wiki": "Ny Wiki",
    "New Word File": "Ny Word-fil",
    "New directories": "Nya kataloger",
    "New file name": "Nytt filnamn",
    "New files": "Nya filer",
    "New folder name": "Nytt mappnamn",
    "New password has been sent to your email {mail}. Please check your mailbox. If you don\u2019t receive the password, please check if your email address is properly configured.": "Nytt l\u00f6senord har skickats till din mailadress {mail}. V\u00e4nligen kontrollera din maill\u00e5da. Om du inte har f\u00e5tt l\u00f6senordet, v\u00e4nligen kontrollera att din mailadress \u00e4r korrekt konfigurerad.",
    "New password is too short": "Det nya l\u00f6senordet \u00e4r f\u00f6r kort",
    "New passwords don't match": "De nya l\u00f6senorden \u00f6verensst\u00e4mmer inte",
    "Next": "N\u00e4sta",
    "No": "Nej",
    "No Admin login logs": "Inga Admin login loggar",
    "No Admin operation logs": "Inga Admin \u00e5tg\u00e4rdsloggar",
    "No connected devices": "Inga anslutna enheter",
    "No deleted libraries": "Inga borttagna kataloger",
    "No departments": "Inga avdelningar",
    "No draft yet": "Inga utkast \u00e4nnu",
    "No favorites": "Inga favoriter",
    "No file access logs": "Inga fil\u00e5tkomstloggar",
    "No file update logs": "Inga filuppdateringsloggar",
    "No folders shared": "Inga mappar delade",
    "No groups": "Inga grupper",
    "No guest invitations": "Inga g\u00e4stinbjudningar",
    "No invitations": "Inga inbjudningar",
    "No libraries": "Inga kataloger",
    "No libraries have been shared directly with you. A shared library can be shared with full or restricted permission. If you need access to a library owned by another user, ask the user to share the library with you.": "Inga kataloger har delats direkt med dig. En delad katalog kan delas med fulla eller restriktiva r\u00e4ttigheter. Om du beh\u00f6ver komma \u00e5t en katalog som \u00e4gs av en annan anv\u00e4ndare. S\u00e5 beh\u00f6ver du be anv\u00e4ndaren att dela katalogen med dig.",
    "No libraries have been shared with this group yet. A library shared with a group can be accessed by all group members. You can share a library with a group in \"My Libraries\". You can also create a new library to be shared with this group by clicking the \"New Library\" button in the menu bar.": "Inga kataloger har delats med denna grupp \u00e4nnu. En katalog som delas med en grupp kan anv\u00e4ndas av alla gruppmedlemmar. Du kan dela en katalog med en grupp i \"Mina Kataloger\". Du kan \u00e4ven skapa en ny katalog som du delar med gruppen genom att klicka p\u00e5 \"Ny Katalog\" knappen i menyn.",
    "No libraries have been shared with you": "Inga bibliotek \u00e4r delade med dig",
    "No libraries have been shared with you from other servers.": "Inga kataloger har inte blivit delad med dig fr\u00e5n andra servrar.",
    "No libraries shared": "Inga kataloger delade",
    "No libraries shared with this group": "Inga kataloger delas med denna grupp",
    "No linked devices": "Inga l\u00e4nkade enheter",
    "No login logs": "Inga login loggar",
    "No members": "Inga Medlemmar",
    "No notifications": "Inga notifikationer",
    "No permission logs": "Inga r\u00e4ttighetsloggar",
    "No preview": "Ingen f\u00f6rhandsvisning",
    "No public libraries": "Inga publika kataloger",
    "No public libraries have been created yet. A public library is accessible by all users. You can create a public library by clicking the \"Add Library\" button in the menu bar.": "Inga publika kataloger har skapats \u00e4nnu. En publik katalog kan alla anv\u00e4ndare komma \u00e5t. Du kan skapa en publik katalog genom att klicka p\u00e5 \"Skapa Katalog\" knappen i menyn",
    "No published libraries": "Inga publicerade kataloger",
    "No result": "Inget resultat",
    "No results matching.": "Inga resultat matchar.",
    "No share links": "Inga delningsl\u00e4nkar",
    "No shared libraries": "Inga delade kataloger",
    "No sub-departments": "Inga underavdelningar",
    "No sync errors": "Inga synkroniseringsfel",
    "No terms and conditions": "Inga villkor",
    "No upload links": "Inga uppladdningsl\u00e4nkar",
    "None": "Ingen",
    "Note: Settings via web interface are saved in database table (seahub-db/constance_config). They have a higher priority over the settings in config files.": "Not: Inst\u00e4llningar via webbgr\u00e4nssnittet \u00e4r sparade i databastabellen (seahub-db/constance_config). De har h\u00f6gre prioritet \u00f6ver inst\u00e4llningar i konfigurationsfiler.",
    "Notification Detail": "Detaljer",
    "Notifications": "Meddelanden",
    "Number of days that keep user sign in.": "Antal dagar som anv\u00e4ndaren h\u00e5lls inloggad.",
    "Number of groups": "Antal grupper",
    "Off": "Av",
    "Old Password": "Gammalt L\u00f6senord",
    "On": "P\u00e5",
    "Online Preview": "Online F\u00f6rhandsvisning",
    "Online Read-Only": "Online L\u00e4s-Endast",
    "Online Read-Only folder": "Online L\u00e4s-Enbart mapp",
    "Online Read-Only library": "Online L\u00e4s-Endast katalog",
    "Online Read-Write": "Online L\u00e4s-Skriv",
    "Online Read-Write folder": "Online L\u00e4s-Skriv mapp",
    "Online Read-Write library": "Online L\u00e4s-Skriva katalog",
    "Online view is not applicable to this file format": "Online-visning \u00e4r inte tillg\u00e4ngligt f\u00f6r detta filformat",
    "Only Show": "Visa Enbart",
    "Only keep a period of history:": "Spara endast historiken ",
    "Open parent directory": "\u00d6ppna f\u00f6r\u00e4ldermapp",
    "Open parent folder": "\u00d6ppna huvudmapp",
    "Open via Client": "\u00d6ppna via Klient",
    "Operation": "\u00c5tg\u00e4rd",
    "Operation succeeded.": "\u00c5tg\u00e4rden lyckades.",
    "Operations": "\u00c5tg\u00e4rder",
    "Organization": "Organisation",
    "Organization Admin": "Organisationsadmin",
    "Organizations": "Organisationer",
    "Other": "Annat",
    "Other Libraries": "Andra Kataloger",
    "Out of quota.": "Slut p\u00e5 kvoten.",
    "Owned Libraries": "\u00c4gda Kataloger",
    "Owner": "\u00c4gare",
    "Owner can use admin panel in an organization, must be a new account.": "\u00c4gare kan inte anv\u00e4nda adminpanelen i en organisation. M\u00e5ste vara ett nytt konto.",
    "Packaging...": "Paketerar...",
    "Password": "L\u00f6senord",
    "Password again": "L\u00f6senord igen",
    "Password is too short": "L\u00f6senordet \u00e4r f\u00f6r kort",
    "Password:": "L\u00f6senord",
    "Passwords do not match.": "L\u00f6senorden matchar inte.",
    "Passwords don't match": "L\u00f6senorden \u00f6verensst\u00e4mmer inte",
    "Path": "S\u00f6kv\u00e4g",
    "Per 4 hours": "Var fj\u00e4rde timme",
    "Per day": "Varje dag",
    "Per hour": "Per timme",
    "Per week": "Varje vecka",
    "Permission": "Beh\u00f6righet",
    "Permission denied": "\u00c5tkomst nekas",
    "Permission denied. Please try {placeholder-left}login again.{placeholder-right}": "\u00c5tkomst nekas. V\u00e4nligen testa {placeholder-left}logga in igen.{placeholder-right}",
    "Permission:": "R\u00e4ttigheter:",
    "Platform": "Plattform",
    "Please check the network.": "Kontrollera n\u00e4tverksanslutningen",
    "Please choose a .xlsx file.": "V\u00e4nligen v\u00e4lj en .xlsx fil.",
    "Please choose an image file.": "V\u00e4nligen ange en bildfil.",
    "Please enter 1 or more character": "V\u00e4nligen ange 1 eller fler tecken",
    "Please enter a new password": "V\u00e4nligen ange det nya l\u00f6senordet",
    "Please enter a non-negative integer": "V\u00e4nligen ange en icke negativ siffra",
    "Please enter a positive integer": "V\u00e4nligen ange ett positivt heltal",
    "Please enter days": "V\u00e4nligen ange antal dagar",
    "Please enter password": "V\u00e4nligen ange l\u00f6senordet",
    "Please enter the new password again": "V\u00e4nligen ange det nya l\u00f6senordet igen",
    "Please enter the old password": "V\u00e4nligen ange det gamla l\u00f6senordet",
    "Please enter the password again": "V\u00e4nligen ange l\u00f6senordet igen",
    "Please input at least an email.": "V\u00e4nligen ange minst en e-postadress.",
    "Please select a library to share.": "V\u00e4lj en katalog att dela.",
    "Please upload files less than {placeholder}M": "V\u00e4nligen ladda upp filer mindre \u00e4n {placeholder}M",
    "Please upload no more than {maxFiles} files at a time.": "V\u00e4nligen ladda inte upp mer \u00e4n {maxFiles} filer \u00e5t g\u00e5ngen.",
    "Preparing to upload...": "F\u00f6rbereder uppladdning...",
    "Preview and download": "F\u00f6rhandsgranska och ladda ner",
    "Preview only": "F\u00f6rhandsgranska enbart",
    "Previous": "Tidigare",
    "Professional Edition": "Professional Edition",
    "Profile": "Profil",
    "Profile Setting": "Profilinst\u00e4llningar",
    "Publish": "Publicera",
    "Publish a Library": "Publicera Katalog",
    "Publish draft": "Publicera utkast",
    "Published Libraries": "Publicerade Kataloger",
    "Quota": "Kvot",
    "Quota is invalid.": "Kvot \u00e4r inte giltig.",
    "Read-Only": "L\u00e4s enbart",
    "Read-Only folder": "L\u00e4s-Enbart mapp",
    "Read-Only library": "Skrivskyddat bibliotek",
    "Read-Write": "L\u00e4s/Skriv",
    "Read-Write folder": "L\u00e4s-Skriv mapp",
    "Read-Write library": "Skrivbart bibliotek",
    "Really want to delete this group?": "Vill du verkligen ta bort denna grupp?",
    "Really want to delete your account?": "Vill du verkligen ta bort ditt konto? ",
    "Really want to leave this group?": "Vill du verkligen l\u00e4mna denna grupp?",
    "Refresh": "Uppdatera",
    "Remaining": "\u00c5terst\u00e5r",
    "Remove": "Ta bort",
    "Remove Member": "Ta bort Medlem",
    "Removed all items from trash.": "Rensade alla objekt fr\u00e5n papperskorgen.",
    "Removed items older than {n} days from trash.": "Rensade objekt som \u00e4r \u00e4ldre \u00e4n {n} dagar fr\u00e5n papperskorgen.",
    "Rename": "D\u00f6p om",
    "Rename File": "D\u00f6p om fil",
    "Rename Folder": "D\u00f6p om Mapp",
    "Rename Group": "D\u00f6p om Grupp",
    "Rename group to": "D\u00f6p om grupp till",
    "Renamed file": "D\u00f6pt om fil",
    "Renamed folder": "D\u00f6pt om mapp",
    "Renamed library": "D\u00f6pte om katalog",
    "Renamed or Moved files": "Omd\u00f6pta eller flyttade filer",
    "Renaming {name} failed": "\u00c4ndra namnet f\u00f6r {name} misslyckades",
    "Replace": "Byta ut",
    "Replace file {filename}?": "Ers\u00e4tt filen {filename}?",
    "Replacing it will overwrite its content.": "Att byta ut dem kommer skriva \u00f6ver inneh\u00e5llet.",
    "Report Abuse": "Rapportera Missbruk",
    "Reporter": "Rapport\u00f6r",
    "Reports": "Rapporter",
    "Request a review": "Efterfr\u00e5ga granskning",
    "Required at least three letters.": "Kr\u00e4vs \u00e5tminstone tre bokst\u00e4ver.",
    "Reset": "\u00c5terst\u00e4ll",
    "Reset Password": "\u00c5terst\u00e4ll L\u00f6senord",
    "Reset library password": "\u00c5terst\u00e4ll katalogsl\u00f6senord",
    "ResetPwd": "ResetPwd",
    "Resetting user's password, please wait for a moment.": "\u00c5terst\u00e4ller anv\u00e4ndarens l\u00f6senord, v\u00e4nligen v\u00e4nta.",
    "Restore": "L\u00e4s tillbaka",
    "Restore Library": "\u00c5terst\u00e4ll Katalog",
    "Restored file": "\u00c5terst\u00e4llt fil",
    "Restored folder": "\u00c5terst\u00e4llt mapp",
    "Restored library": "\u00c5terst\u00e4llt katalog",
    "Result": "Resultat",
    "Retry": "F\u00f6rs\u00f6k igen",
    "Retry All": "F\u00f6rs\u00f6k igen med Alla",
    "Revoke": "Degradera",
    "Revoke Access": "Ta bort Tilltr\u00e4de",
    "Revoke Admin": "Degradera admin",
    "Role": "Roll",
    "Save": "Spara",
    "Save as ...": "Spara som ...",
    "Save to:": "Spara till:",
    "Saving...": "Sparar...",
    "Seafile": "Seafile",
    "Search": "S\u00f6k",
    "Search Groups": "S\u00f6k Grupper",
    "Search Libraries": "S\u00f6k Kataloger",
    "Search Organizations": "S\u00f6k Organisationer",
    "Search Users": "S\u00f6k Anv\u00e4ndare",
    "Search files in this library": "S\u00f6k efter filer i denna katalog",
    "Search groups": "S\u00f6k grupper",
    "Search groups by name": "S\u00f6k grupper med namn",
    "Search libraries by owner": "S\u00f6k kataloger med \u00e4gare",
    "Search organizations": "S\u00f6k organisationer",
    "Search users": "S\u00f6k anv\u00e4ndare",
    "Select File": "V\u00e4lj Fil",
    "Select Image": "V\u00e4lj Bild",
    "Select Tags": "V\u00e4lj Taggar",
    "Select a color": "V\u00e4lj en f\u00e4rg",
    "Select a department": "V\u00e4lj en avdelning",
    "Select a group": "V\u00e4lj en grupp",
    "Select a user": "V\u00e4lj en anv\u00e4ndare",
    "Select groups": "V\u00e4lj grupper",
    "Select libraries to share": "V\u00e4lj kataloger att dela",
    "Send": "Skicka",
    "Send activation Email after user registration.": "Skicka aktiverings-mejl efter anv\u00e4ndarregistrering.",
    "Send to:": "Skicka till:",
    "Sending new password...": "Skickar nytt l\u00f6senord...",
    "Sending...": "Skickar...",
    "Server": "Server",
    "Server Version: ": "Serverversion: ",
    "Set Admin": "S\u00e4tt admin",
    "Set Contact Email": "S\u00e4tt Kontaktmail",
    "Set Login ID": "S\u00e4tt Login ID",
    "Set Name": "S\u00e4tt Namn",
    "Set Password": "S\u00e4tt l\u00f6senord",
    "Set Quota": "S\u00e4tt kvot",
    "Set Reference ID": "S\u00e4tt Referens ID",
    "Set max number of members": "S\u00e4tt max antal medlemmar",
    "Set permission": "Set r\u00e4ttigheter",
    "Set to current": "S\u00e4tt som aktuellt systemmeddelande",
    "Set user contact email": "S\u00e4tt anv\u00e4ndarkontakt mejl",
    "Set user name": "S\u00e4tt anv\u00e4ndarens namn",
    "Set user quota": "S\u00e4tt anv\u00e4ndarkvot",
    "Set {placeholder}'s permission": "S\u00e4tt {placeholder}s r\u00e4ttigheter",
    "Setting library history is disabled by Admin.": "Inst\u00e4llningen katalogshistorik \u00e4r avst\u00e4ngd av Admin",
    "Settings": "Inst\u00e4llningar",
    "Share": "Dela",
    "Share Admin": "Administrera delningar",
    "Share From": "Dela fr\u00e5n",
    "Share Link": "Dela L\u00e4nk",
    "Share Link Traffic": "Delningsl\u00e4nk Trafik",
    "Share Links": "Delningsl\u00e4nkar",
    "Share To": "Dela med",
    "Share To:": "Dela Till:",
    "Share existing libraries": "Dela existerande kataloger",
    "Share link download": "Delningsl\u00e4nk nedladdat",
    "Share link is copied to the clipboard.": "Delningsl\u00e4nk \u00e4r kopierat till urklipp",
    "Share link upload": "Delningsl\u00e4nk uppladdat",
    "Share to group": "Dela till grupp",
    "Share to other server": "Dela till annan server",
    "Share to user": "Dela till anv\u00e4ndare",
    "Shared By": "Delad av",
    "Shared Libraries": "Delade Kataloger",
    "Shared Links": "Delade L\u00e4nkar",
    "Shared by:": "Delas av:",
    "Shared by: ": "Delad av:",
    "Shared from other servers": "Delad fr\u00e5n andra servrar",
    "Shared with all": "Delade med alla",
    "Shared with groups": "Delade med grupper",
    "Shared with me": "Delade med mig",
    "Show": "Visa",
    "Show Codes": "Visa Koder",
    "Side Nav Menu": "Sidomeny",
    "Site name used in email sending": "Sidnamn som anv\u00e4nds i mejlutskick",
    "Site title shown in a browser tab": "Sidtiteln som visas i en webbl\u00e4sartabb",
    "Size": "Storlek",
    "Social Login": "Social Login",
    "Space Used": "Anv\u00e4nt utrymme",
    "Space Used / Quota": "Utrymme Anv\u00e4nt / Kvot",
    "Star": "Favorit",
    "Start date": "Startdatum",
    "Statistic": "Statistik",
    "Status": "Status",
    "Status: enabled": "Status: aktiverad",
    "Storage": "Utrymme",
    "Storage Backend": "Lagringsyta",
    "Storage Used": "Anv\u00e4nt Utrymme",
    "Sub-departments": "Underavdelningar",
    "Submit": "OK",
    "Success": "Lyckades",
    "Successfully added label(s) for library {placeholder}": "Lyckades l\u00e4gga till markering(ar) till katalogen {placeholder}",
    "Successfully added {email_placeholder}": "Lyckades l\u00e4gga till {email_placeholder}",
    "Successfully changed library password.": "\u00c4ndrade l\u00f6senord f\u00f6r katalogen.",
    "Successfully cleaned all errors.": "Lyckades rensa alla fel.",
    "Successfully cleared trash.": "Lyckades rensa papperskorg.",
    "Successfully copied %(name)s and %(amount)s other items.": "Lyckades kopiera %(name)s och %(amount)s andra filer.",
    "Successfully copied %(name)s and 1 other item.": "Lyckades kopiera %(name)s och 1 annan fil.",
    "Successfully copied %(name)s.": "Lyckades kopiera %(name)s.",
    "Successfully copied files to another library.": "Lyckades kopiera filer till en annan katalog.",
    "Successfully deleted 1 item": "Lyckades ta bort 1 sak",
    "Successfully deleted 1 item.": "Lyckades ta bort 1 sak.",
    "Successfully deleted 1 user.": "Lyckades ta bort 1 anv\u00e4ndare.",
    "Successfully deleted draft %(draft)s.": "Lyckades ta bort utkast %(draft)s.",
    "Successfully deleted {name}": "Lyckades ta bort {name}",
    "Successfully deleted {name}.": "Lyckades ta bort {name}.",
    "Successfully deleted {user_number_placeholder} users.": "Lyckades ta bort {user_number_placeholder} anv\u00e4ndare.",
    "Successfully edited labels.": "Lyckades \u00e4ndra markeringar.",
    "Successfully invited %(email) and %(num) other people.": "Lyckades bjuda in %(email) och %(num) andra personer.",
    "Successfully invited %(email).": "Lyckades bjuda in %(email).",
    "Successfully modified permission.": "Lyckades modifiera r\u00e4ttigheter.",
    "Successfully moved %(name)s and %(amount)s other items.": "Lyckades flytta %(name)s och %(amount)s andra filer.",
    "Successfully moved %(name)s and 1 other item.": "Lyckades flytta %(name)s och 1 annan fil.",
    "Successfully moved %(name)s.": "Lyckades flytta %(name)s.",
    "Successfully moved files to another library.": "Lyckades flytta filer till en annan katalog.",
    "Successfully moved {name}.": "Lyckades flytta {name}.",
    "Successfully published draft %(draft)s.": "Lyckades publicera utkast %(draft)s.",
    "Successfully removed {placeholder}.": "Lyckades ta bort {placeholder}.",
    "Successfully reset password to %(passwd)s for user %(user)s.": "\u00c5terst\u00e4llde l\u00f6senord till %(passwd)s f\u00f6r anv\u00e4ndare %(user)s.",
    "Successfully restored 1 item.": "Lyckades \u00e5terst\u00e4lla 1 fil.",
    "Successfully restored the library.": "Lyckades \u00e5terst\u00e4lla katalogen.",
    "Successfully restored.": "Lyckades \u00e5terst\u00e4lla.",
    "Successfully revoke the admin permission of %s": "Tog bort adminbeh\u00f6righet f\u00f6r %s",
    "Successfully revoked access of user {placeholder}.": "Lyckades ta bort tilltr\u00e4de f\u00f6r anv\u00e4ndare {placeholder}.",
    "Successfully revoked the admin permission of {placeholder}.": "Lyckades ta bort adminr\u00e4ttigheter f\u00f6r {placeholder}.",
    "Successfully saved": "Lyckades spara",
    "Successfully sent to {placeholder}": "Lyckades skicka till {placeholder}",
    "Successfully set %s as admin.": "Lyckades s\u00e4tta %s som admin.",
    "Successfully set it.": "Lyckades s\u00e4tta den.",
    "Successfully set library history.": "Satte katalogens historik.",
    "Successfully starred {library_name_placeholder}.": "{library_name_placeholder} las till favoriter.",
    "Successfully transferred the group.": "Gruppen \u00f6verf\u00f6rd.",
    "Successfully transferred the library.": "Biblioteket \u00f6verf\u00f6rdes.",
    "Successfully unlinked %(name)s.": "Lyckades avl\u00e4nka %(name)s.",
    "Successfully unlinked the device.": "Lyckades avl\u00e4nka enheten",
    "Successfully unshared library {placeholder}": "Slutade dela bibliotek {placeholder}",
    "Successfully unshared {name}": "Lyckades avl\u00e4nka {name}",
    "Successfully unstarred {library_name_placeholder}.": "{library_name_placeholder} togs bort fr\u00e5n favoriter.",
    "Suggestion": "F\u00f6rslag",
    "Switch to plain text editor": "Byt till enkel textredigerare",
    "Switch to rich text editor": "Byt till ut\u00f6kad textredigerare",
    "Sync": "Synka",
    "Sync Download": "Synk-nedladdning",
    "Sync Traffic": "Synk Trafik",
    "Sync Upload": "Synk-uppladdning",
    "System": "System",
    "System Admin": "Systemadmin",
    "System Info": "Systeminformation",
    "Tag \"{name}\" already exists.": "Taggen \"{name}\" existerar redan.",
    "Tagged Files": "Taggade Filer",
    "Tags": "Taggar",
    "Template": "Mall",
    "Terms": "Villkor",
    "Terms and Conditions": "Villkor",
    "Text": "Text",
    "Text files": "Textfiler",
    "Text is required.": "Text kr\u00e4vs.",
    "The URL of the server, like https://seafile.example.com or http://192.168.1.2:8000": "Serverns URL. T.ex. https://seafile.example.com eller http://192.168.1.2:8000",
    "The file is too large. Allowed maximum size is 1MB.": "Denna fil \u00e4r f\u00f6r stor. Till\u00e5ten maxstorlek \u00e4r 1MB.",
    "The internal URL for downloading/uploading files. Users will not be able to download/upload files if this is not set correctly. If you config Seafile behind Nginx/Apache, it should be SERVICE_URL/seafhttp, like https://seafile.example.com/seafhttp .": "Intern URL f\u00f6r att ladda ner/upp filer. Anv\u00e4ndare kommer inte kunna ladda ner/upp filer om detta inte \u00e4r r\u00e4tt inst\u00e4llt. Om du anv\u00e4nder Seafile bakom Nginx/Apache detta ska vara SERVICE_URL/seafhttp. T.ex. https://seafile.example.com/seafhttp .",
    "The least number of characters an account password should include.": "Det l\u00e4gsta antal tecken som ett kontos l\u00f6senord ska inneh\u00e5lla.",
    "The least number of characters an encrypted library password should include.": "Det l\u00e4gsta antal tecken som ett krypterat biblioteks l\u00f6senord ska inneh\u00e5lla.",
    "The level(1-4) of an account password's strength. For example, '3' means password must have at least 3 of the following: num, upper letter, lower letter and other symbols": "Styrkeniv\u00e5 (1-4) f\u00f6r ett kontos l\u00f6senord. Exempelvis betyder '3' att ett l\u00f6senord m\u00e5ste ha minst 3 av f\u00f6ljande: siffra, versal, gemen och andra symboler.",
    "The link is copied to the clipboard.": "L\u00e4nken \u00e4r kopierad till urklipp.",
    "The list of added, deleted and modified files will be sent to your mailbox.": "Lista med tillagda, borttagna och \u00e4ndrade filer har skickats till din maill\u00e5da.",
    "The maximum number of failed login attempts before showing CAPTCHA.": "Maximalt antal misslyckade inloggningar innan en CAPTCHA visas.",
    "The name \"{name}\" is already taken. Please choose a different name.": "Namnet \"{name}\" anv\u00e4nds redan. V\u00e4lj ett annat namn.",
    "The owner of this library has run out of space.": "\u00c4garen av denna katalog har slut p\u00e5 ledigt diskutrymme.",
    "The password will be kept in the server for only 1 hour.": "L\u00f6senordet kommer sparas p\u00e5 servern endast en timme",
    "This file has been updated.": "Denna fil har blivit uppdaterad.",
    "This file is in draft stage.": "Denna fil \u00e4r i ett utkast l\u00e4ge.",
    "This folder has no content at this time.": "Denna mapp har inget inneh\u00e5ll just nu.",
    "This is a special group representing a department.": "Detta \u00e4r en speciell grupp som representerar en avdelning.",
    "This library has been set to read-only by admin and cannot be updated.": "Denna katalog har satts med enbart l\u00e4s r\u00e4ttigheter av admin och kan inte uppdateras.",
    "This library is password protected": "Katalogen \u00e4r l\u00f6senordsskyddad",
    "This operation will not be reverted. Please think twice!": "Denna \u00e5tg\u00e4rd kan inte \u00e5ngras. T\u00e4nk efter innan!",
    "Time": "Tid",
    "Tip: -2 means no limit.": "Tips: -2 betyder ingen begr\u00e4nsning.",
    "Tip: 0 means default limit": "Tips: 0 betyder standardbegr\u00e4nsning",
    "Tip: a snapshot will be generated after modification, which records the library state after the modification.": "Tips: En \u00f6gonblicksbild kommer skapas efter f\u00f6r\u00e4ndring, vilket sparar bibliotekets tillst\u00e5nd efter f\u00f6r\u00e4ndringen.",
    "Tip: libraries deleted {placeholder} days ago will be cleaned automatically.": "Tips: kataloger som \u00e4r borttagna f\u00f6r {placeholder} dagar sedan kommer rensas automatiskt.",
    "Tip: libraries deleted {trashReposExpireDays} days ago will be cleaned automatically.": "Tips: kataloger borttagna {trashReposExpireDays} dagar sedan kommer rensas automatiskt.",
    "Tip: you can search by keyword in name.": "Tips: du kan s\u00f6ka genom att ange nyckelord namnet.",
    "Token": "K\u00e4nnetecken",
    "Tools": "Verktyg",
    "Total Devices": "Total Enheter",
    "Total Storage": "Total Yta",
    "Total Traffic": "Total trafik",
    "Total Users": "Totalt antal anv\u00e4ndare",
    "Traffic": "Trafik",
    "Transfer": "\u00d6verf\u00f6r",
    "Transfer Group": "\u00d6verf\u00f6r grupp",
    "Transfer Group {placeholder} to": "\u00d6verf\u00f6r Grupp {placeholder} till",
    "Transfer Library": "\u00d6verf\u00f6r bibliotek",
    "Transfer Library {library_name}": "\u00d6verf\u00f6r Katalogen {library_name}",
    "Transfer group to": "\u00d6verf\u00f6r grupp till",
    "Transfer to department": "\u00d6verf\u00f6r till avdelning",
    "Transfer to user": "\u00d6verf\u00f6r till anv\u00e4ndare",
    "Transferred group {group_name} from {user_from} to {user_to}": "\u00d6verf\u00f6rde grupp {group_name} fr\u00e5n {user_from} till {user_to}",
    "Transferred library {library_name} from {user_from} to {user_to}": "\u00d6verf\u00f6rde bibliotek {library_name} fr\u00e5n {user_from} till {user_to}",
    "Trash": "Papperskorg",
    "Two-Factor Authentication": "Tv\u00e5faktorsautentisering",
    "Two-factor authentication is not enabled for your account. Enable two-factor authentication for enhanced account security.": "Tv\u00e5faktorsautentisering \u00e4r inte till\u00e5ten f\u00f6r ditt konto. Aktivera tv\u00e5faktorsautentisering f\u00f6r h\u00f6gre kontos\u00e4kerhet.",
    "Type": "Typ",
    "Unhandled": "Ohanterad",
    "Unknown": "Ok\u00e4nd",
    "Unlink": "Avl\u00e4nka",
    "Unlink device": "Avl\u00e4nka enhet",
    "Unlock": "L\u00e5s upp",
    "Unpublish": "Avpublicera",
    "Unpublish Library": "Avpublicera Katalog",
    "Unshare": "Sluta dela",
    "Unshare Library": "Sluta dela bibliotek",
    "Unstar": "Ta bort favorit",
    "Update": "Uppdatera",
    "Update Terms and Conditions": "Uppdatera villkor",
    "Update succeeded.": "Uppdatering lyckades.",
    "Updated draft": "Uppdaterat utkast",
    "Updated file": "Uppdaterat fil",
    "Upgrade to Pro Edition": "Uppgradera till Pro Edition",
    "Upload": "Ladda upp",
    "Upload Files": "Ladda upp filer",
    "Upload Folder": "Ladda upp mapp",
    "Upload Link": "Uppladdningsl\u00e4nk",
    "Upload Link:": "Uppladdningsl\u00e4nk:",
    "Upload Links": "Uppladdningsl\u00e4nkar",
    "Upload file": "Ladda upp fil",
    "Upload files to {folder_name_placeholder}": "Ladda upp filer till {folder_name_placeholder}",
    "Upload license": "Ladda upp licens",
    "Upload link is copied to the clipboard.": "Uppladdnignsl\u00e4nk kopierad till urklipp.",
    "Uploaded": "Uppladdad",
    "Use custom CSS": "Anv\u00e4nds egen CSS",
    "Use draft": "Anv\u00e4nd utkast",
    "Used:": "Anv\u00e4nt",
    "User": "Anv\u00e4ndare",
    "User Email": "Anv\u00e4ndarmail",
    "User Permission": "Anv\u00e4ndarr\u00e4ttigheter",
    "User Storage": "Anv\u00e4ndarutrymme",
    "User can only view files online via browser. Files can't be downloaded.": "Anv\u00e4ndare kan se filer online via webbl\u00e4saren. Filer kan inte laddas ned.",
    "User can read, download and sync files.": "Anv\u00e4ndare kan l\u00e4sa, ladda ned och synka filer.",
    "User can read, write, upload, download and sync files.": "Anv\u00e4ndare kan l\u00e4sa, skriva, ladda upp, ladda ned och synka filer.",
    "User can view and edit file online via browser. Files can't be downloaded.": "Anv\u00e4ndare kan l\u00e4sa och redigera filer online via webbl\u00e4saren. Filer kan inte laddas ned.",
    "User not found": "Anv\u00e4ndare hittades inte",
    "User {user_link} has added you to {group_link}": "Anv\u00e4ndaren {user_link} har lagt till dig till {group_link}",
    "Username:": "Anv\u00e4ndarnamn:",
    "Users": "Anv\u00e4ndare",
    "Verify": "Verifiera",
    "Version": "Version",
    "Version Number": "Versions Nummer",
    "Version Number is required.": "Versionsnummer kr\u00e4vs.",
    "Version Number must be a number.": "Versionsnummer m\u00e5ste vara en siffra.",
    "Video": "Video",
    "View": "Visa",
    "View Draft": "Visa Utkast",
    "View Link": "Visa L\u00e4nk",
    "View Snapshot": "Visa Snapshot",
    "View profile and more": "Visa profil och mer",
    "Virus": "Virus",
    "Virus File": "Virusfil",
    "Virus Scan": "Virusscan",
    "Visited": "Bes\u00f6kte",
    "Visits": "Bes\u00f6k",
    "Web API Auth Token": "Web API Auth Token",
    "Web Download": "Webb-nedladdning",
    "Web Traffic": "Webb Trafik",
    "Web Upload": "Webb-uppladdning",
    "WebDav Password": "WebDav L\u00f6senord",
    "Welcome to {site_name_placeholder}": "V\u00e4lkommen till {site_name_placeholder}",
    "Wrong password": "Fel l\u00f6senord",
    "Yes": "Ja",
    "You are not in any groups. Groups allow multiple people to collaborate on libraries. Groups you join will be listed here.": "Du \u00e4r inte i n\u00e5gon grupp. Grupper till\u00e5ter flera personer att samarbeta med kataloger. Grupper som du g\u00e5r med i kommer listas h\u00e4r.",
    "You are not in any groups. Groups allow multiple people to collaborate on libraries. You can create a group by clicking the \"New Group\" button in the menu bar.": "Du \u00e4r inte i n\u00e5gon grupp. Grupper till\u00e5ter flera personer att samarbeta med kataloger. Du kan skapa en grupp genom att klicka p\u00e5 \"Ny Grupp\" knappen i menyn.",
    "You can also add a user as a guest, who will not be allowed to create libraries and groups.": "Du kan ocks\u00e5 l\u00e4gga till en anv\u00e4ndare som g\u00e4st, som inte kommer kunna skapa kataloger eller grupper.",
    "You can create files quickly": "Du kan skapa filer snabbt",
    "You can create libraries by clicking the \"New Library\" button above.": "Du kan skapa kataloger genom att klicka p\u00e5 \"Ny Katalog\" knappen ovan.",
    "You can use this field at login.": "Du kan anv\u00e4nda detta f\u00e4lt vid inloggning.",
    "You don't have any favorite items yet": "Du har inga favoritobjekt \u00e4nnu",
    "You don't have any share links": "Du har inga delningsl\u00e4nkgar",
    "You don't have any upload links": "Du har inga uppladdningsl\u00e4nkar",
    "You have an unsaved draft. Do you like to use it?": "Du har ett osparat utkast. Vill du l\u00e4gga till den?",
    "You have not accessed your files with any client (desktop or mobile) yet. Configure clients on your devices to access your data more comfortably.": "Du har inte \u00f6ppnat dina filer med n\u00e5gon klient (skrivbord eller mobil) \u00e4nnu. Konfigurera klienter p\u00e5 dina enheter f\u00f6r att komma \u00e5t din data enklare.",
    "You have not added any libraries, folders or files to your favorites yet. A favorite gives you quick access to your most frequently used objects. You can add a library, folder or file to your favorites by clicking the star to the left of its name.": "Du har inte lagt till n\u00e5gra kataloger, mappar eller filer till dina favoriter \u00e4nnu. En favorit ger dig snabbt \u00e5tkomst till dina mest frekvent anv\u00e4nda objekt. Du kan l\u00e4gga till en katalog, mapp eller fil till dina favoriter genom att klicka p\u00e5 stj\u00e4rnan till v\u00e4nster om dess namn.",
    "You have not created any libraries yet. A library is a container to organize your files and folders. A library can also be shared with others and synced to your connected devices. You can create a library by clicking the \"New Library\" button in the menu bar.": "Du har inte skapat n\u00e5gra kataloger \u00e4nnu. En katalog \u00e4r en container f\u00f6r att organisera dina filer och mappar. En katalog kan \u00e4ven delas med andra och synkroniseras med dina anslutna enheter. Du kan skapa en katalog genom att klicka p\u00e5 \"Ny Katalog\" knappen i menyn.",
    "You have not created any share links yet. A share link can be used to share files and folders with anyone. You can create a share link for a file or folder by clicking the share icon to the right of its name.": "Du har inte skapat n\u00e5gra delningsl\u00e4nkar \u00e4nnu. En delningsl\u00e4nk kan anv\u00e4ndas av anv\u00e4ndare till att dela filer och mappar med vem som helst. Du kan skapa en delningsl\u00e4nk f\u00f6r en fil eller mapp genom att klicka p\u00e5 delningsikonen till h\u00f6ger om dess namn.",
    "You have not created any upload links yet. An upload link allows anyone to upload files to a folder or library. You can create an upload link for a folder or library by clicking the share icon to the right of its name.": "Du har inte skapat en uppladdningsl\u00e4nk \u00e4nnu. En uppladdningsl\u00e4nk till\u00e5ter vem som helst att ladda upp filer till en mapp eller katalog. Du kan skapa en uppladdningsl\u00e4nk f\u00f6r en mapp eller katalog genom att klicka p\u00e5 delningsikonen till h\u00f6ger om dess namn.",
    "You have not deleted any libraries in the last {placeholder} days. A deleted library will be cleaned automatically after this period.": "Du har inte tagit bort n\u00e5gra kataloger de senaste {placeholder} dagar. En borttagen katalog kommer att rensas automatiskt efter denna period.",
    "You have not invited any guests yet. A guest can access shared libraries through the web interface allowing more efficient ways to collaborate than through links. You can invite a guest by clicking the \"Invite Guest\" button in the menu bar.": "Du har inte bjudit in n\u00e5gra g\u00e4ster \u00e4nnu. En g\u00e4st kan \u00f6ppna delade kataloger genom webbgr\u00e4nssnittet, vilket till\u00e5ter mer effektiva v\u00e4gar att samarbeta \u00e4n genom l\u00e4nkar. Du kan bjuda in en g\u00e4st genom att klicka p\u00e5 \"Bjud in G\u00e4st\" knappen i menyn.",
    "You have not published any libraries yet. A published library can be accessed by anyone, not only users, via its URL. You can publish a library by clicking the \"Publish a Library\" button in the menu bar.": "Du har inte publicerat n\u00e5gra kataloger \u00e4nnu. En publicerad katalog kan anv\u00e4ndas av alla, inte bara anv\u00e4ndare, genom dess URL. Du kan publicera en katalog genom att klicka p\u00e5 \"Publicera Katalog\" knappen i menyn.",
    "You have not shared any folders": "Du har inte delat n\u00e5gra mappar",
    "You have not shared any folders with other users yet. You can share a folder with other users by clicking the share icon to the right of a folder's name.": "Du har inte delat n\u00e5gra mappar med andra anv\u00e4ndare \u00e4nnu. Du kan dela en mapp med andra anv\u00e4ndare genom att klicka p\u00e5 delningsikonen till h\u00f6ger om en mapps namn.",
    "You have not shared any libraries with other users yet. You can share a library with other users by clicking the share icon to the right of a library's name in \"My Libraries\".": "Du har inte delat n\u00e5gra kataloger med andra anv\u00e4ndare \u00e4nnu. Du kan dela en katalog med andra anv\u00e4ndare genom att klicka p\u00e5 dela ikonen till h\u00f6ger om en katalogs namn i \"Mina Kataloger\".",
    "You have only one backup code remaining.": "Du har bara en backupkod kvar.",
    "You have {num} backup codes remaining.": "Du har {num} backupkoder kvar.",
    "Your notifications will be sent to this email.": "Dina notifikationer kommer att skickas till denna mejladress.",
    "ZIP": "ZIP",
    "ZIP Selected Items": "ZIP Valda Objekt",
    "activate after registration": "aktivera efter registrering",
    "all": "alla",
    "all members": "alla medlemmar",
    "allow new registrations": "till\u00e5t nya registreringar",
    "days": "dagar",
    "deleted": "borttagen",
    "details": "detaljer",
    "email is required": "mailadress kr\u00e4vs",
    "icon": "ikon",
    "keep sign in": "h\u00e5ll inloggad",
    "library password minimum length": "minimil\u00e4ngd f\u00f6r biblioteks l\u00f6senord",
    "licensed to {placeholder_license_to}, expires on {placeholder_license_expiration}": "licensierad till {placeholder_license_to}, l\u00f6per ut {placeholder_license_expiration}",
    "licensed to {placeholder_license_to}, upgrade service expired in {placeholder_license_expiration}": "licensierad till {placeholder_license_to}, uppgraderingsservice l\u00f6per ut {placeholder_license_expiration}",
    "locked": "l\u00e5st",
    "locked by {name}": "l\u00e4st av {name}",
    "name": "namn",
    "password minimum length": "l\u00f6senords minimil\u00e4ngd",
    "password strength level": "l\u00f6senords styrkeniv\u00e5",
    "progress": "g\u00e5ng",
    "result": "resultat",
    "results": "resultat",
    "send activation email": "skicka aktiverings-mejl",
    "shared by:": "delat av:",
    "show more": "visa mer",
    "size": "storlek",
    "starred": "favorit skapad",
    "state": "tillst\u00e5nd",
    "successfully added user %s.": "lyckades l\u00e4gga till anv\u00e4ndare %s.",
    "text file extensions": "textfils\u00e4ndelser",
    "to": "till",
    "unstarred": "favorit borttagen",
    "you can also press \u2190 ": "du kan ocks\u00e5 trycka  \u2190 ",
    "you can also press \u2192": "du kan ocks\u00e5 trycka \u2192",
    "{file} and {n} other files": "{file} och {n} andra filer",
    "{from_user} has sent you a request for {draft_link}.": "{from_user} har skickat dig en efterfr\u00e5gan f\u00f6r {draft_link}.",
    "{minDays_placeholder} - {maxDays_placeholder} days": "{minDays_placeholder} - {maxDays_placeholder} dagar",
    "{number_placeholder} / Page": "{number_placeholder} / Sida",
    "{placeholder} API Token": "{placeholder} API Token",
    "{placeholder} Folder Permission": "{placeholder} Mappr\u00e4ttigheter",
    "{placeholder} Modification History": "{placeholder} \u00c4ndringshistorik",
    "{placeholder} Snapshot": "{placeholder} \u00d6gonblicksbild",
    "{placeholder} Trash": "{placeholder} Papperskorg",
    "{share_from} has shared a folder named {repo_link} to group {group_link}.": "{share_from} har delat mappen med namnet {repo_link} till gruppen {group_link}.",
    "{share_from} has shared a folder named {repo_link} to you.": "{share_from} har delat en mapp med namnet {repo_link} med dig.",
    "{share_from} has shared a library named {repo_link} to group {group_link}.": "{share_from} har delat en katalog med namnet {repo_link} till gruppen {group_link}.",
    "{share_from} has shared a library named {repo_link} to you.": "{share_from} har delat katalogen {repo_link} till dig.",
    "{site_name_placeholder} organizes files into libraries. Each library can be synced and shared separately. However, since you are a guest user now, you can not create libraries.": "{site_name_placeholder} organiserar filer in i kataloger. Varje katalog kan synkroniseras och delas separat. Men, eftersom du \u00e4r en g\u00e4stanv\u00e4ndare, s\u00e5 kan du inte skapa kataloger.",
    "{site_name_placeholder} organizes files into libraries. Each library can be synced and shared separately. We have created a personal library for you. You can create more libraries later.": "{site_name_placeholder} organiserar filer in i kataloger. Varje katalog kan synkroniseras och delas separat. Vi har skapat en personlig katalog \u00e5t dig. Du kan skapa fler kataloger senare.",
    "{userCount} user(s) and {repoCount} libraries of this organization will also be deleted.": "{userCount} anv\u00e4ndare och {repoCount} kataloger i denna organisation kommer ocks\u00e5 att tas bort.",
    "{user} has transfered a library named {repo_link} to you.": "{user} har \u00f6verf\u00f6rt en katalog med namnet {repo_link} till dig."
  };
  for (const key in newcatalog) {
    django.catalog[key] = newcatalog[key];
  }
  

  if (!django.jsi18n_initialized) {
    django.gettext = function(msgid) {
      const value = django.catalog[msgid];
      if (typeof value === 'undefined') {
        return msgid;
      } else {
        return (typeof value === 'string') ? value : value[0];
      }
    };

    django.ngettext = function(singular, plural, count) {
      const value = django.catalog[singular];
      if (typeof value === 'undefined') {
        return (count == 1) ? singular : plural;
      } else {
        return value.constructor === Array ? value[django.pluralidx(count)] : value;
      }
    };

    django.gettext_noop = function(msgid) { return msgid; };

    django.pgettext = function(context, msgid) {
      let value = django.gettext(context + '\x04' + msgid);
      if (value.includes('\x04')) {
        value = msgid;
      }
      return value;
    };

    django.npgettext = function(context, singular, plural, count) {
      let value = django.ngettext(context + '\x04' + singular, context + '\x04' + plural, count);
      if (value.includes('\x04')) {
        value = django.ngettext(singular, plural, count);
      }
      return value;
    };

    django.interpolate = function(fmt, obj, named) {
      if (named) {
        return fmt.replace(/%\(\w+\)s/g, function(match){return String(obj[match.slice(2,-2)])});
      } else {
        return fmt.replace(/%s/g, function(match){return String(obj.shift())});
      }
    };


    /* formatting library */

    django.formats = {
    "DATETIME_FORMAT": "j F Y H:i",
    "DATETIME_INPUT_FORMATS": [
      "%Y-%m-%d %H:%M:%S",
      "%Y-%m-%d %H:%M:%S.%f",
      "%Y-%m-%d %H:%M",
      "%m/%d/%Y %H:%M:%S",
      "%m/%d/%Y %H:%M:%S.%f",
      "%m/%d/%Y %H:%M",
      "%m/%d/%y %H:%M:%S",
      "%m/%d/%y %H:%M:%S.%f",
      "%m/%d/%y %H:%M",
      "%Y-%m-%d"
    ],
    "DATE_FORMAT": "j F Y",
    "DATE_INPUT_FORMATS": [
      "%Y-%m-%d",
      "%m/%d/%Y",
      "%m/%d/%y"
    ],
    "DECIMAL_SEPARATOR": ",",
    "FIRST_DAY_OF_WEEK": 1,
    "MONTH_DAY_FORMAT": "j F",
    "NUMBER_GROUPING": 3,
    "SHORT_DATETIME_FORMAT": "Y-m-d H:i",
    "SHORT_DATE_FORMAT": "Y-m-d",
    "THOUSAND_SEPARATOR": "\u00a0",
    "TIME_FORMAT": "H:i",
    "TIME_INPUT_FORMATS": [
      "%H:%M:%S",
      "%H:%M:%S.%f",
      "%H:%M"
    ],
    "YEAR_MONTH_FORMAT": "F Y"
  };

    django.get_format = function(format_type) {
      const value = django.formats[format_type];
      if (typeof value === 'undefined') {
        return format_type;
      } else {
        return value;
      }
    };

    /* add to global namespace */
    globals.pluralidx = django.pluralidx;
    globals.gettext = django.gettext;
    globals.ngettext = django.ngettext;
    globals.gettext_noop = django.gettext_noop;
    globals.pgettext = django.pgettext;
    globals.npgettext = django.npgettext;
    globals.interpolate = django.interpolate;
    globals.get_format = django.get_format;

    django.jsi18n_initialized = true;
  }
};

